@@ -1,13 +1,24 @@
 negate_ <- function(e, ...){
-  # don't do double negation: that complicates analysis of expressions
   op <- node(e)
 
+  # don't do double negation: that complicates analysis of expressions
   if (op == '!'){
-    return(e[[2]])
+    return(consume(e[[2]]))
   }
 
   expr <- if (is.call(e) && op != '('){
-    substitute( !(e), list(e=e) )
+    if (op == "!="){
+      substitute( l == r, list(l = left(e), r = right(e)))
+    } else if (op == "=="){
+      if (is.logical(right(e))){
+        substitute( l == r, list(l = left(e), r = !right(e)))
+      } else {
+        substitute( l != r, list(l = left(e), r = right(e)))
+      }
+    }
+    else {
+      substitute( !(e), list(e=e) )
+    }
   } else {
     substitute( !e, list(e=e))
   }
